% WARNING: Running this code removes all variables from the current
% workspace, and closes current figures.
clear all
close all
home

% Modified by Jiayi Sun 2022-06-07
%{
An example MATLAB code that uses dataset Keefe_2017 that includes subjects 
with different ear pathologies and multiple sweep directions and demonstrates 
how to plot mean absorbance for the different ear pathologies at ambient
pressure.

Made with MATLAB R2022a
Please install Statistics Toolbox to use some functions inside the code.
%}


% Load in tables from database via MySQL 
% Note: file name should match the file name you saved on your computer
data = readtable('WAI_Measurements_2022-06-06.csv');
Subjects_Table = readtable('WAI_Subjects_2022-06-06.csv');


% Only use PI we are checking
PI = 'Keefe_2017';
data=data(strcmp(data.Identifier, PI),:);
Subjects_Table = Subjects_Table(strcmp(Subjects_Table.Identifier, PI),:);

% Get frequencies and subject numbers
Frequency = unique(data.Frequency);
SubjectNumbers=unique(data.SubjectNumber);
NumberSubjects=length(SubjectNumbers);


% Get Normal Hearing (NH), Otosclerosis (OS), and Post Surgical Data at Ambient pressure

% Get the rows in the dataset that include ambient and normal hearing data
ambientNH_rows = find(strcmp(data.SweepDirection, 'Ambient') & strcmp(data.EarStatus, 'Normal'));
% Create a table that includes only the data from ambient and normal hearing
ambientNHData = data(ambientNH_rows,:);
% Get the subect number and number of subjects for normal hearing and ambient
SubjectNumbersNH = unique(ambientNHData.SubjectNumber);
NumberSubjectsNH = length(SubjectNumbersNH);

% Go through the same process above, but for OS data
ambientOS_rows = find(strcmp(data.SweepDirection, 'Ambient') & strcmp(data.EarStatus, 'OS'));
ambientOSData = data(ambientOS_rows,:); 
SubjectNumbersOS = unique(ambientOSData.SubjectNumber);
NumberSubjectsOS = length(SubjectNumbersOS);


% Go through the same process above, but for post surgical data
ambientSur_rows = find(strcmp(data.SweepDirection, 'Ambient') & strcmp(data.EarStatus, 'Post Surgical'));
ambientSurData = data(ambientSur_rows,:);
SubjectNumbersSur = unique(ambientSurData.SubjectNumber);
NumberSubjectsSur = length(SubjectNumbersSur);

%{
Since there is only one session per subject, we can go through all the 
frequencies and find the mean Absorbance at each frequency this only works 
when there is only one session per subject because if some subjects had 
three sessions but another had two and then another only had one, the mean 
would be more affected by the subject with three sessions, so it wouldn't 
be accurate
%}

% Get mean Absorbance ready to plot for normal hearing data (ambient)
AbsorbanceNH = [];
% Index loops through each frequency
for freq_index = 1:length(Frequency)
    % Find all the rows with the same frequency
    freq_rows = find(ambientNHData.Frequency==Frequency(freq_index));
    % Create an array of the absorbance at each frequency
    AbsorbanceNH = [AbsorbanceNH; ambientNHData.Absorbance(freq_rows).'];
    % Get the mean of the absorbance at each frequency
    mean_AbsNH = nanmean(AbsorbanceNH,2);
end

% Get mean Absorbance ready to plot for OS data (ambient)
AbsorbanceOS = [];
% Index loops through each frequency
for freq_index = 1:length(Frequency)
    % Find all the rows with the same frequency
    freq_rows = find(ambientOSData.Frequency==Frequency(freq_index));
    % Create an array of the absorbance at each frequency
    AbsorbanceOS = [AbsorbanceOS; ambientOSData.Absorbance(freq_rows).'];
    % Get the mean of the absorbance at each frequency
    mean_AbsOS = nanmean(AbsorbanceOS,2);
end

% Get mean Absorbance ready to plot for Post Surgical data (ambient)
AbsorbanceSur = [];
% Index loops through each frequency
for freq_index = 1:length(Frequency)
    % Find all the rows with the same frequency
    freq_rows = find(ambientSurData.Frequency==Frequency(freq_index));
    % Create an array of the absorbance at each frequency
    AbsorbanceSur = [AbsorbanceSur; ambientSurData.Absorbance(freq_rows).'];
    % Get the mean of the absorbance at each frequency
    mean_AbsSur = nanmean(AbsorbanceSur,2);
end



% Plot mean absorbance for normal hearing, OS, amd Posy Surgical data at ambient pressure
figure(1)
set(gcf, 'Position', [100, 100, 600, 500])
sgtitle('Keefe et al. (2017)', 'FontSize', 20)
semilogx(Frequency, mean_AbsNH, 'b', 'LineWidth', 2)
xlim([100 10000])
ylim([0 1])
xlabel('Frequency (Hz)')
ylabel('Absorbance')
title('Ambient Absorbance')
hold on
semilogx(Frequency, mean_AbsOS, 'g', 'LineWidth', 2)
semilogx(Frequency, mean_AbsSur, 'r', 'LineWidth', 2)
legend('Normal Hearing', 'Otosclerosis', 'Post Surgical')
hold off
